@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use namespace::clean;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -17,11 +17,6 @@ our $VERSION = '0.02';
 
 CSV::HistoryPlayer - Plays scattered CSV files with historic data
 
-=head1 VERSION
-
-0.02
-
-
 =head1 STATUS
 
 =begin HTML
@@ -333,7 +328,6 @@ sub poll {
     return $result;
 }
 
-
 =head1 AUTHOR
 
 binary.com, C<< <perl at binary.com> >>
@@ -385,5 +379,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-
 1;
